==> ksquirrel-trinity-3.5.13.2.tar.xz: ksquirrel-trinity-3.5.13.2/ksquirrel/sq_filethumbviewitem.h <==
/***************************************************************************
                          sq_filethumbviewitem.h  -  description
                             -------------------
    begin                : ??? ??? 12 2004
    copyright            : (C) 2004 by Baryshev Dmitry
    email                : ksquirrel.iv@gmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SQ_FILETHUMBVIEWITEM_H
#define SQ_FILETHUMBVIEWITEM_H

#include <tqpixmap.h>

#include <kfileiconview.h>

/*
 *  SQ_FileThumbViewItem represents a thumbnail item in SQ_FileThumbView.
 *  Additianally it stores some useful info.
 */

class SQ_FileThumbViewItem : public KFileIconViewItem
{
    public: 
        SQ_FileThumbViewItem(TQIconView *parent, const TQString &text, const TQPixmap &pixmap, KFileItem *fi);
        ~SQ_FileThumbViewItem();

        bool listed() const;

        void setListed(bool l);

    protected:
        /*
         *  Painting routines.
         */
        virtual void paintItem(TQPainter *p, const TQColorGroup &cg);
        virtual void paintFocus(TQPainter *p, const TQColorGroup &cg);
        void paintText(TQPainter *p, const TQColorGroup &c);

    private:
        bool m_listed;
};

inline
bool SQ_FileThumbViewItem::listed() const
{
    return m_listed;
}

inline
void SQ_FileThumbViewItem::setListed(bool l)
{
    m_listed = l;
}

#endif

==> ksquirrel-trinity-14.1.1.tar.xz: ksquirrel-trinity-14.1.1/ksquirrel/sq_filethumbviewitem.h <==
/***************************************************************************
                          sq_filethumbviewitem.h  -  description
                             -------------------
    begin                : ??? ??? 12 2004
    copyright            : (C) 2004 by Baryshev Dmitry
    email                : ksquirrel.iv@gmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SQ_FILETHUMBVIEWITEM_H
#define SQ_FILETHUMBVIEWITEM_H

#include <tqpixmap.h>

#include <tdefileiconview.h>

/*
 *  SQ_FileThumbViewItem represents a thumbnail item in SQ_FileThumbView.
 *  Additianally it stores some useful info.
 */

class SQ_FileThumbViewItem : public KFileIconViewItem
{
    public: 
        SQ_FileThumbViewItem(TQIconView *parent, const TQString &text, const TQPixmap &pixmap, KFileItem *fi);
        ~SQ_FileThumbViewItem();

        bool listed() const;

        void setListed(bool l);

    protected:
        /*
         *  Painting routines.
         */
        virtual void paintItem(TQPainter *p, const TQColorGroup &cg);
        virtual void paintFocus(TQPainter *p, const TQColorGroup &cg);
        void paintText(TQPainter *p, const TQColorGroup &c);

    private:
        bool m_listed;
};

inline
bool SQ_FileThumbViewItem::listed() const
{
    return m_listed;
}

inline
void SQ_FileThumbViewItem::setListed(bool l)
{
    m_listed = l;
}

#endif
